@@ -1,14 +1,27 @@
 <?php
+/**
+ *
+ * @package MediaWiki
+ * @subpackage SpecialPage
+ */
 
-function wfSpecialVersion()
-{
+/**
+ * constructor
+ */
+function wfSpecialVersion() {
 	global $wgUser, $wgOut, $wgVersion;
 	$fname = "wfSpecialVersion";
 
+	$prefix = wfMsg( 'special_version_prefix' );
+	$postfix = wfMsg( 'special_version_postfix' );
+	if( $prefix != '&nbsp;' ) {
+		$wgOut->addWikiText( $prefix );
+	}
 	$wgOut->addHTML( '
+<div dir="ltr">
  <p>This wiki is powered by <b><a href="http://www.mediawiki.org/">MediaWiki</a></b>,  
- copyright (C) 2001-2004 by Magnus Manske, Brion Vibber, Lee Daniel Crocker,
- Tim Starling, Erik M&ouml;ller, and others.</p>
+ copyright (C) 2001-2005 by Magnus Manske, Brion Vibber, Lee Daniel Crocker,
+ Tim Starling, Erik M&ouml;ller, Gabriel Wicke, and others.</p>
  
  <p>MediaWiki is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -24,14 +37,20 @@ function wfSpecialVersion()
  along with this program; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  or <a href="http://www.gnu.org/copyleft/gpl.html">read it online</a></p>
-	');
+</div>');
+	if( $postfix != '&nbsp;' ) {
+		$wgOut->addWikiText( $postfix );
+	}
 	$versions = array(
 		"[http://wikipedia.sf.net/ MediaWiki]" => $wgVersion,
-		"[http://www.php.net/ PHP]" => phpversion() . " (" . php_sapi_name() . ")",
-		"[http://www.mysql.com/ MySQL]" => mysql_get_server_info()
+		"[http://www.php.net/ PHP]" => phpversion() . " (" . php_sapi_name() . ")"
  	);
+ 	
+ 	$dbr =& wfGetDB( DB_SLAVE );
+ 	$dblink = $dbr->getSoftwareLink();
+ 	$versions[$dblink] = $dbr->getServerVersion();
 	
-	$out = "";
+	$out = '';
 	foreach( $versions as $module => $ver ) {
 		$out .= ":$module: $ver\n";
 	}
