@@ -30,8 +30,8 @@ default:
     NS_TALK             => "Dyskusja",
     NS_USER             => "Wikipedysta",
     NS_USER_TALK        => "Dyskusja_Wikipedysty",
-    NS_WIKIPEDIA        => $wgMetaNamespace,
-    NS_WIKIPEDIA_TALK   => $wgMetaTalkNamespace,  // see above
+    NS_PROJECT          => $wgMetaNamespace,
+    NS_PROJECT_TALK     => $wgMetaTalkNamespace,   // see above
     NS_IMAGE            => "Grafika",
     NS_IMAGE_TALK       => "Dyskusja_grafiki",
     NS_MEDIAWIKI        => "MediaWiki",
@@ -48,76 +48,6 @@ default:
         "Brak", "Stały, z lewej", "Stały, z prawej", "Unoszący się, z lewej"
 );
 
-/* private */ $wgSkinNamesPl = array(
-	'standard' => "Standard",
-	'nostalgia' => "Nostalgia",
-	'cologneblue' => "Cologne Blue",
-	'smarty' => "Paddington",
-	'montparnasse' => "Montparnasse",
-	'davinci' => "DaVinci",
-	'mono' => "Mono",
-	'monobook' => "MonoBook",
- "myskin" => "MySkin" 
-);
-
-/* private */ $wgMathNamesPl = array( 
-    "Zawsze jako PNG",
-        "HTML dla prostych, dla reszty PNG",
-        "Spróbuj HTML; jeśli zawiedzie, to PNG",
-        "Pozostaw w TeXu (tekst)",
-        "HTML, dla nowszych przeglądarek"
-); 
-
-/* private */ $wgUserTogglesPl = array(
-        "hover" => "Pokazuj okienko podpowiedzi ponad linkami",
-        "underline" => "Podkreślenie linków",
-        "highlightbroken" => "<a href=\"\" class=\"new\">Podświetl</a> linki pustych stron (alternatywa: znak zapytania<a href=\"\" class=\"internal\">?</a>).",
-        "justify" => "Wyrównuj tekst artykułu w kolumnie",
-        "hideminor" => "Ukryj drobne zmiany w \"Ostatnich zmianach\"",
-        "usenewrc" => "Konsolidacja ostatnich zmian (JavaScript)",
-        "numberheadings" => "Automatyczna numeracja nagłówków",
-	"showtoolbar" => "Show edit toolbar",
-        "editondblclick" => "Podwójne kliknięcie rozpoczyna edycję (JavaScript)",
-                "editsection" => "Możliwość edycji poszczególnych sekcji strony",
-                "editsectiononrightclick" => "Kliknięcie prawym klawiszem na tytule sekcji<br>rozpoczyna jej edycję (JavaScript)",
-                "showtoc" =>  "Spis treści (na stronach zawierających więcej niż 3 nagłówki)",
-        "rememberpassword" => "Pamiętaj hasło między sesjami",
-        "editwidth" => "Obszar edycji o pełnej szerokości",
-        "watchdefault" => "Obserwuj strony, które będę edytować",
-        "minordefault" => "Wszystkie zmiany zaznaczaj domyślnie jako drobne",
-        "previewontop" => "Pokazuj podgląd przed oknem edycji",
-                "nocache" => "Wyłącz pamięć podręczną"
-);
-
-/* private */ $wgBookstoreListPl = array(
-        "AddALL" => "http://www.addall.com/New/Partner.cgi?query=$1&type=ISBN",
-        "PriceSCAN" => "http://www.pricescan.com/books/bookDetail.asp?isbn=$1",
-        "Barnes & Noble" => "http://shop.barnesandnoble.com/bookSearch/isbnInquiry.asp?isbn=$1",
-        "Amazon.com" => "http://www.amazon.com/exec/obidos/ISBN=$1"
-);
-
-/* private */ $wgWeekdayNamesPl = array(
-        "niedziela", "poniedziałek", "wtorek", "środa", "czwartek",
-        "piątek", "sobota"
-);
-
-/* private */ $wgMonthNamesPl = array(
-        "styczeń", "luty", "marzec", "kwiecień", "maj", "czerwiec",
-        "lipiec", "sierpień", "wrzesień", "październik", "listopad",
-        "grudzień"
-);
-
-/* private */ $wgMonthNamesGenPl = array(
-        "stycznia", "lutego", "marca", "kwietnia", "maja", "czerwca",
-        "lipca", "sierpnia", "września", "października", "listopada",
-        "grudnia"
-);
-
-/* private */ $wgMonthAbbreviationsPl = array(
-        "sty", "lut", "mar", "kwi", "maj", "cze", "lip", "sie",
-        "wrz", "paź", "lis", "gru"
-);
-
 # All special pages have to be listed here: a description of ""
 # will make them not show up on the "Special Pages" page, which
 # is the right thing for some of them (such as the "targeted" ones).
@@ -171,6 +101,73 @@ default:
 );
 
 /* private */ $wgAllMessagesPl = array(
+'special_version_prefix' => '',
+'special_version_postfix' => '',
+# User Toggles
+
+"tog-hover" => "Pokazuj okienko podpowiedzi ponad linkami",
+"tog-underline" => "Podkreślenie linków",
+"tog-highlightbroken" => "<a href=\"\" class=\"new\">Podświetl</a> linki pustych stron (alternatywa: znak zapytania<a href=\"\" class=\"internal\">?</a>).",
+"tog-justify" => "Wyrównuj tekst artykułu w kolumnie",
+"tog-hideminor" => "Ukryj drobne zmiany w \"Ostatnich zmianach\"",
+"tog-usenewrc" => "Konsolidacja ostatnich zmian (JavaScript)",
+"tog-numberheadings" => "Automatyczna numeracja nagłówków",
+"tog-showtoolbar" => "Show edit toolbar",
+"tog-editondblclick" => "Podwójne kliknięcie rozpoczyna edycję (JavaScript)",
+"tog-editsection" => "Możliwość edycji poszczególnych sekcji strony",
+"tog-editsectiononrightclick" => "Kliknięcie prawym klawiszem na tytule sekcji<br />rozpoczyna jej edycję (JavaScript)",
+"tog-showtoc" =>  "Spis treści (na stronach zawierających więcej niż 3 nagłówki)",
+"tog-rememberpassword" => "Pamiętaj hasło między sesjami",
+"tog-editwidth" => "Obszar edycji o pełnej szerokości",
+"tog-watchdefault" => "Obserwuj strony, które będę edytować",
+"tog-minordefault" => "Wszystkie zmiany zaznaczaj domyślnie jako drobne",
+"tog-previewontop" => "Pokazuj podgląd przed oknem edycji",
+"tog-nocache" => "Wyłącz pamięć podręczną",
+
+# Dates
+'sunday' => "niedziela",
+'monday' => "poniedziałek",
+'tuesday' => "wtorek",
+'wednesday' => "środa",
+'thursday' => "czwartek",
+'friday' => "piątek",
+'saturday' => "sobota",
+'january' => "styczeń",
+'february' => "luty",
+'march' => "marzec",
+'april' => "kwiecień",
+'may_long' => "maj",
+'june' => "czerwiec",
+'july' => "lipiec",
+'august' => "sierpień",
+'september' => "wrzesień",
+'october' => "październik",
+'november' => "listopad",
+'december' => "grudzień",
+'january-gen' => "stycznia",
+'february-gen' => "lutego",
+'march-gen' => "marca",
+'april-gen' => "kwietnia",
+'may-gen' => "maja",
+'june-gen' => "czerwca",
+'july-gen' => "lipca",
+'august-gen' => "sierpnia",
+'september-gen' => "września",
+'october-gen' => "października",
+'november-gen' => "listopada",
+'december-gen' => "grudnia",
+'jan' => "sty",
+'feb' => "lut",
+'mar' => "mar",
+'apr' => "kwi",
+'may' => "maj",
+'jun' => "cze",
+'jul' => "lip",
+'aug' => "sie",
+'sep' => "wrz",
+'oct' => "paź",
+'nov' => "lis",
+'dec' => "gru",
 
 # Bits of text used by many pages:
 #
@@ -182,7 +179,7 @@ default:
 "mainpage" => "Strona główna",
 "mainpagetext" => "Instalacja oprogramowania powiodła się.",
 "about" => "O Wikipedii",
-"aboutwikipedia" => "O Wikipedii",
+"aboutsite"      => "O Wikipedii",
 "aboutpage" => "{{ns:4}}:O_Wikipedii",
 "help" => "Pomoc",
 "helppage" => "{{ns:4}}:Pomoc",
@@ -207,7 +204,7 @@ default:
 "currentevents" => "-",
 "errorpagetitle" => "Błąd",
 "returnto" => "Wróć do strony: $1.",
-"fromwikipedia" => "Z Wikipedii, wolnej encyklopedii.",
+"tagline"       => "Z Wikipedii, wolnej encyklopedii.",
 "whatlinkshere" => "Strony, które odwołują się do tej",
 "help" => "Pomoc",
 "search" => "Szukaj",
@@ -272,8 +269,6 @@ specjalnej strony.",
 "error" => "Błąd",
 "databaseerror" => "Błąd bazy danych",
 "dberrortext" => "Wystąpił błąd składni w zapytaniu do bazy danych.
-Mogło to być spowodowane przez złe sformułowanie zapytania (zobacz $5)
-albo przez błąd w oprogramowaniu.
 Ostatnie, nieudane zapytanie to:
 <blockquote><tt>$1</tt></blockquote>
 wysłane przez funkcję \"<tt>$2</tt>\".
@@ -340,8 +335,8 @@ Nie zapomnij dostosować <i>preferencji</i>.",
 "yourpasswordagain" => "Powtórz hasło",
 "newusersonly" => " (tylko nowi użytkownicy)",
 "remembermypassword" => "Pamiętaj moje hasło między sesjami.",
-"loginproblem" => "<b>Są problemy z Twoim logowaniem.</b><br>Spróbuj ponownie!",
-"alreadyloggedin" => "<font color=red><b>$1, jesteś już zalogowany!</b></font><br>\n",
+"loginproblem" => "<b>Są problemy z Twoim logowaniem.</b><br />Spróbuj ponownie!",
+"alreadyloggedin" => "<font color=red><b>$1, jesteś już zalogowany!</b></font><br />\n",
 
 "login" => "Zaloguj mnie",
 "userlogin" => "Logowanie",
@@ -382,7 +377,7 @@ Po otrzymaniu go zaloguj się ponownie.",
 "showpreview" => "Podgląd",
 "blockedtitle" => "Użytkownik jest zablokowany",
 "blockedtext" => "Twoje konto lub adres IP zostały zablokowane przez $1.
-Podany powód to:<br>$2.<p>W celu wyjaśnienia sprawy zablokowania możesz się skontaktować z $1 lub innym
+Podany powód to:<br />$2.<p>W celu wyjaśnienia sprawy zablokowania możesz się skontaktować z $1 lub innym
 [[{{ns:4}}:Administratorzy|administratorem]].",
 "newarticle" => "(Nowy)",
 "newarticletext" => "Nie ma jeszcze artykułu o tym tytule. W poniższym polu można wpisać pierwszy jego fragment. Jeśli nie to było Twoim zamiarem, wciśnij po prostu ''Wstecz''.",
@@ -399,8 +394,8 @@ nie są skierowane do Ciebie, [[Specjalna:Userlogin|utwórz proszę konto i/albo
 "previewconflict" => "Wersja podglądana odnosi się do tekstu
 z górnego pola edycji. Tak będzie wyglądać strona jeśli zdecydujesz się ją zapisać.",
 "editing" => "Edytujesz \"$1\"",
-"sectionedit" => " (fragment)",
-"commentedit" => " (komentarz)",
+"editingsection" => "Edytujesz \"$1\" (fragment)",
+"editingcomment" => "Edytujesz \"$1\" (komentarz)",
 "editconflict" => "Konflikt edycji: $1",
 "explainconflict" => "Ktoś zdążył wprowadzić swoją wersję artykułu
 w trakcie Twojej edycji.
@@ -416,9 +411,9 @@ Jeśli zapiszesz ją wszystkie późniejsze zmiany zostaną skasowane.</strong><
 "yourdiff" => "Różnice",
 "copyrightwarning" => "Proszę pamiętać o tym, że przyjmuje się, iż wszelki
 wkład do Wikipedii jest udostępniany na zasadach <i>GNU Free Documentation License</i>
-(szczegóły w $1).  <br>Jeśli nie chcesz, żeby Twój tekst był dowolnie zmieniany przez każdego i rozpowszechniany bez ograniczeń, nie umieszczaj go w Wikipedii.  Niniejszym jednocześnie oświadczasz, że ten tekst jest Twoim dziełem lub pochodzi z materiałów dostępnych na zasadach <i>public domain</i> albo
+(szczegóły w $1).  <br />Jeśli nie chcesz, żeby Twój tekst był dowolnie zmieniany przez każdego i rozpowszechniany bez ograniczeń, nie umieszczaj go w Wikipedii.  Niniejszym jednocześnie oświadczasz, że ten tekst jest Twoim dziełem lub pochodzi z materiałów dostępnych na zasadach <i>public domain</i> albo
 licencji <i>GNU Free Documentation License</i> lub kompatybilnej.
-<br><strong>PROSZĘ NIE UŻYWAĆ BEZ POZWOLENIA MATERIAŁÓW OBJĘTYCH PRAWEM
+<br /><strong>PROSZĘ NIE UŻYWAĆ BEZ POZWOLENIA MATERIAŁÓW OBJĘTYCH PRAWEM
 AUTORSKIM!</strong>",
 "longpagewarning" => "UWAGA: Ta strona ma $1 kilobajt-y/-ów; w przypadku niektórych
 przeglądarek mogą wystąpić problemy w edycji stron mających więcej niż 32 kilobajty.
@@ -462,9 +457,7 @@ Sprawdź proszę URL użyty przez Ciebie by uzyskać dostęp do tej strony.\n",
 # Search results
 #
 "searchresults" => "Wyniki wyszukiwania",
-"searchhelppage" => "{{ns:4}}:Przeszukiwanie",
-"searchingwikipedia" => "Przeszukiwanie Wikipedii",
-"searchresulttext" => "Aby dowiedzieć się więcej o przeszukiwaniu Wikipedii, zobacz $1.",
+"searchresulttext" => "Aby dowiedzieć się więcej o przeszukiwaniu Wikipedii, zobacz [[Project:Przeszukiwanie|Przeszukiwanie Wikipedii]].",
 "searchquery" => "Dla zapytania \"$1\"",
 "badquery" => "Źle sformułowane zapytanie",
 "badquerytext" => "Nie można zrealizować Twojego zapytania.
@@ -489,35 +482,14 @@ zapytaniu więcej niż jednego słowa (na liście odnalezionych stron znajdą si
 tylko te, które zawierają wszystkie podane słowa).",
 "powersearch" => "Szukaj", 
 "powersearchtext" => "
-Szukaj w przestrzeniach nazw :<br>
-$1<br>
+Szukaj w przestrzeniach nazw :<br />
+$1<br />
 $2 Pokaż przekierowania   Szukany tekst $3 $9",
 "searchdisabled" => "<p>Ze względu na duże obciążenie serwera wyszukiwanie
 w treści artykułów zostało czasowo wyłączone; mamy nadzieję, że 
 po zbliżającej się modyfikacji sprzętu możliwość ta zostanie przywrócona.
 W międzyczasie polecamy wyszukiwanie za pomocą Google:</p>
 
-",
-"googlesearch" => "<!-- SiteSearch Google -->
-<FORM method=GET action=\"http://www.google.com/search\">
-<TABLE bgcolor=\"#FFFFFF\"><tr><td>
-<A HREF=\"http://www.google.com/\">
-<IMG SRC=\"http://www.google.com/logos/Logo_40wht.gif\"
-border=\"0\" ALT=\"Google\"></A>
-</td>
-<td>
-<INPUT TYPE=text name=q size=31 maxlength=255 value=\"$1\">
-<INPUT type=submit name=btnG VALUE=\"Google Search\">
-<font size=-1>
-<input type=hidden name=domains value=\"{$wgServer}\"><br><input type=radio
-name=sitesearch value=\"\"> WWW <input type=radio name=sitesearch
-value=\"{$wgServer}\" checked> {$wgServer} <br>
-<input type='hidden' name='ie' value='$2'>
-<input type='hidden' name='oe' value='$2'>
-</font>
-</td></tr></TABLE>
-</FORM>
-<!-- SiteSearch Google -->
 ",
 "blanknamespace" => "(Główna)",
 
@@ -527,7 +499,7 @@ value=\"{$wgServer}\" checked> {$wgServer} <br>
 "preferences" => "Preferencje",
 "prefsnologin" => "Brak logowania",
 "prefsnologintext" => "Musisz się <a href=\"" .
-  wfLocalUrl( "Specjalna:Userlogin" ) . "\">zalogować</a>
+  "{{localurle:Specjalna:Userlogin}}\">zalogować</a>
 przez zmianą swoich preferencji.",
 "prefslogintext" => "Zalogowano Cię jako \"$1\". Twój numer identyfikacyjny to $2.
 
@@ -601,38 +573,41 @@ Jeśli zależy Ci na dalszym rozwoju Wikipedii, nie dodawaj materiałów zastrze
 "reuploaddesc" => "Wróć do formularza wysyłki.",
 "uploadnologin" => "Brak logowania",
 "uploadnologintext" => "Musisz się <a href=\"" .
-  wfLocalUrl( "Specjalna:Userlogin" ) . "\">zalogować</a>
+  "{{localurle:Specjalna:Userlogin}}\">zalogować</a>
 przed przesłaniem pików.",
 "uploadfile" => "Prześlij plik",
 "uploaderror" => "Błąd przesyłki",
-"uploadtext" => "<strong>STOP!</strong> Zanim prześlesz plik,
-przeczytaj <a href=\"" . wfLocalUrlE( "{{ns:4}}:Zasady_dołączania_plików" ) .
-"\">zasady dołączania plików</a> i upewnij się, że przesyłając pozostaniesz z
+"uploadtext" => "'''STOP!''' Zanim prześlesz plik,
+przeczytaj [[Project:Zasady_dołączania_plików|zasady dołączania plików]]
+i upewnij się, że przesyłając pozostaniesz z
 nimi w zgodzie.
-<p>Jeśli chcesz przejrzeć lub przeszukać dotychczas przesłane pliki,
-przejdź do <a href=\"" . wfLocalUrlE( "Specjalna:Imagelist" ) .
-"\">listy dołączonych plików</a>.
+
+Jeśli chcesz przejrzeć lub przeszukać dotychczas przesłane pliki,
+przejdź do [[Specjalna:Imagelist|listy dołączonych plików]].
 Wszystkie przesyłki i skasowania są odnotowane na
-specjalnych wykazach (<a href=\"" .  wfLocalUrlE( "{{ns:4}}:Dołączone" ) .
-"\">dołączone</a>, <a href=\"" . wfLocalUrlE( "{{ns:4}}:Usunięte" ) .
-"\">usunięte</a>).
-<p>By przesłać nowy plik mający zilustrować Twój artykuł skorzystaj
+specjalnych wykazach ([[Project:Dołączone|dołączone]],
+[[Project:Usunięte|usunięte]]).
+
+By przesłać nowy plik mający zilustrować Twój artykuł skorzystaj
 z poniższego formularza.
-W przypadku większości przeglądarek zobaczysz przycisk <i>Browse...</i>
-albo <i>Przeglądaj...</i>, który umożliwi Ci otworzenie standardowego
+W przypadku większości przeglądarek zobaczysz przycisk ''Browse...''
+albo ''Przeglądaj...'', który umożliwi Ci otworzenie standardowego
 okienka wyboru pliku. Wybranie pliku spowoduje umieszczenie jego nazwy
 w polu tekstowym obok przycisku.
 Musisz także zaznaczając odpowiednie pole, potwierdzić, że przesyłając
 plik nie naruszasz niczyich praw autorskich.
-Przesyłka rozpocznie się po naciśnięciu <i>Prześlij plik</i>.
+Przesyłka rozpocznie się po naciśnięciu ''Prześlij plik''.
 Może zająć kilka chwil, zwłaszcza jeśli masz wolne połączenie z internetem.
-<p>Preferowane formaty to JPEG dla zdjęć fotograficznych, PNG dla rysunków
+
+Preferowane formaty to JPEG dla zdjęć fotograficznych, PNG dla rysunków
 i obrazków o charakterze ikon oraz OGG dla dźwięków.
 Aby uniknąć nieporozumień nadawaj plikom nazwy związane z zawartością.
 Aby umieścić obrazek w artykule, użyj linku w postaci
-<b>[[grafika:obrazek.jpg]]</b> lub <b>[[grafika:obrazek.png|opcjonalny tekst]]</b>.
-Dla plików dźwiękowych link będzie miał postać <b>[[media:file.ogg]]</b>.
-<p>Pamiętaj, proszę, że tak jak w przypadku zwykłych stron Wikipedii,
+'''<nowiki>[[grafika:obrazek.jpg]]</nowiki>''' lub
+'''<nowiki>[[grafika:obrazek.png|opcjonalny tekst]]</nowiki>'''.
+Dla plików dźwiękowych link będzie miał postać '''<nowiki>[[media:file.ogg]]</nowiki>'''.
+
+Pamiętaj, proszę, że tak jak w przypadku zwykłych stron Wikipedii,
 inni użytkownicy mogą edytować lub kasować przesłane przez Ciebie pliki,
 jeśli stwierdzą, że to będzie lepiej służyć całemu projektowi.
 Twoje prawo do przesyłania może zostać Ci odebrane, jeśli nadużyjesz systemu.",
@@ -688,7 +663,7 @@ i cokolwiek co wiesz o pliku, a wydaje Ci się ważne.",
 "deleteimgcompletely" => "usuń",
 "imghistlegend" => "Legenda: (bież) = to jest obecny plik, (usuń) = usuń
 tę starszą wersję, (przywróć) = przywróć tę starszą wersję.
-<br><i>Kliknij na datę aby zobaczyć jakie pliki przesłano tego dnia</i>.",
+<br /><i>Kliknij na datę aby zobaczyć jakie pliki przesłano tego dnia</i>.",
 "imagelinks" => "Linki do pliku",
 "linkstoimage" => "Oto strony odwołujące się do tego pliku:",
 "nolinkstoimage" => "Żadna strona nie odwołuje się do tego pliku.",
@@ -720,13 +695,13 @@ więc, by ich nie nadużywać.",
 "disambiguationspage" => "{{ns:4}}:Strony_ujednoznaczniające",
 "disambiguationstext" => "Poniższe artykuły odwołują się do <i>stron
 ujednoznaczniających</i>, a powinny odwoływać się bezpośrednio do hasła
-związanego z treścią artykułu.<br>Strona uznawana jest za ujednoznaczniającą
-jeśli odwołuje się do niej $1.<br>Linki z innych przestrzeni nazw <i>nie</i>
+związanego z treścią artykułu.<br />Strona uznawana jest za ujednoznaczniającą
+jeśli odwołuje się do niej $1.<br />Linki z innych przestrzeni nazw <i>nie</i>
 zostały tu uwzględnione.",
 "doubleredirects" => "Podwójne przekierowania",
 "doubleredirectstext" => "<b>Uwaga:</b> Na tej liście mogą znajdować się
 przekierowania pozorne. Oznacza to, że poniżej pierwszej linii artykułu,
-zawierającej \"#REDIRECT ...\", może znajdować się dodatkowy tekst.<br>Każdy
+zawierającej \"#REDIRECT ...\", może znajdować się dodatkowy tekst.<br />Każdy
 wiersz listy zawiera odwołania do pierwszego i drugiego przekierowania oraz
 pierwszą linię tekstu drugiego przekierowania. Umożliwia to w większości
 przypadków odnalezienie właściwego artykułu, do którego powinno się
@@ -790,9 +765,9 @@ a ta lista nie powinna być interpretowana jako świadectwo udziału w zyskach."
 #
 "mailnologin" => "Brak adresu",
 "mailnologintext" => "Musisz się <a href=\"" .
-  wfLocalUrl( "Specjalna:Userlogin" ) . "\">zalogować</a>
+  "{{localurle:Specjalna:Userlogin}}\">zalogować</a>
 i mieć wpisany aktualny adres e-mailowy w swoich <a href=\"" .
-  wfLocalUrl( "Specjalna:Preferences" ) . "\">preferencjach</a>,
+  "{{localurle:Specjalna:Preferences}}\">preferencjach</a>,
 aby móc wysłać e-mail do innych użytkowników.",
 "emailuser" => "Wyślij e-mail do tego użytkownika",
 "emailpage" => "Wyślij e-mail do użytkownika",
@@ -818,14 +793,14 @@ albo zadecydował, że nie chce otrzymywać e-maili od innych użytkowników.",
 "nowatchlist" => "Nie ma żadnych pozycji na liście obserwowanych przez Ciebie stron.",
 "watchnologin" => "Brak logowania",
 "watchnologintext" => "Musisz się <a href=\"" .
-  wfLocalUrl( "Specjalna:Userlogin" ) . "\">zalogować</a>
+  "{{localurle:Specjalna:Userlogin}}\">zalogować</a>
 przed modyfikacją listy obserwowanych artykułów.",
 "addedwatch" => "Dodana do listy obserwowanych",
 "addedwatchtext" => "Strona \"$1\" została dodana do Twojej <a href=\"" .
-  wfLocalUrl( "Specjalna:Watchlist" ) . "\">listy obserwowanych</a>.
+  "{{localurle:Specjalna:Watchlist}}\">listy obserwowanych</a>.
 Na tej liście znajdzie się rejestr przyszłych zmian tej strony i stowarzyszonej z nią strony Dyskusji,
 a nazwa samej strony zostanie <b>wytłuszczona</b> na <a href=\"" .
-  wfLocalUrl( "Specjalna:Recentchanges" ) . "\">liście ostatnich zmian</a> aby
+  "{{localurle:Specjalna:Recentchanges}}\">liście ostatnich zmian</a> aby
 łatwiej było Ci sam fakt zmiany zauważyć.</p>
 
 <p>Jeśli chcesz usunąć stronę ze swojej listy obserwowanych, kliknij na
@@ -902,7 +877,7 @@ Autorem ostatniej zmiany jest teraz [[Wikipedysta:$3|$3]] ([[Dyskusja_wikipedyst
 "undelete" => "Odtwórz skasowaną stronę",
 "undeletepage" => "Odtwarzanie skasowanych stron",
 "undeletepagetext" => "Poniższe strony zostały skasowane, ale ich kopia wciąż
-znajduje się w archiwum.<br><b>Uwaga:</b> archiwum co jakiś czas także jest kasowane!",
+znajduje się w archiwum.<br /><b>Uwaga:</b> archiwum co jakiś czas także jest kasowane!",
 "undeletearticle" => "Odtwórz skasowaną stronę",
 "undeleterevisions" => "Liczba zarchiwizowanych wersji: $1",
 "undeletehistory" => "Odtworzenie strony spowoduje przywrócenie także jej
@@ -955,7 +930,7 @@ się wandalizmu).",
 "noblockreason" => "Musisz podać powód blokady.",
 "blockipsuccesssub" => "Zablokowanie powiodło się",
 "blockipsuccesstext" => "Adres IP \"$1\" został zablokowany.
-<br>Przejdź do [[Specjalna:Ipblocklist|Listy zablokowanych adresów IP]] by przejrzeć blokady.",
+<br />Przejdź do [[Specjalna:Ipblocklist|Listy zablokowanych adresów IP]] by przejrzeć blokady.",
 "unblockip" => "Odblokuj adres IP",
 "unblockiptext" => "Użyj poniższego formularza by przywrócić prawa zapisu
 dla poprzednio zablokowanego adresu IP.",
@@ -988,7 +963,7 @@ Potwierdź, proszę, że to jest zgodne z Twoimi zamiarami.",
 "lockdbsuccesssub" => "Baza danych została pomyślnie zablokowana",
 "unlockdbsuccesssub" => "Blokada bazy danych usunięta",
 "lockdbsuccesstext" => "Baza danych Wikipedii została zablokowana.
-<br>Pamiętaj usunąć blokadę po zakończeniu spraw administracyjnych.",
+<br />Pamiętaj usunąć blokadę po zakończeniu spraw administracyjnych.",
 "unlockdbsuccesstext" => "Baza danych Wikipedii została odblokowana.",
 
 # SQL query
@@ -1035,7 +1010,7 @@ Możesz też zrezygnować z przeniesienia dyskusji (poniższy <i>checkbox</i>)."
 "movearticle" => "Przenieś stronę",
 "movenologin" => "Brak logowania",
 "movenologintext" => "Musisz być zarejestrowanym i <a href=\"" .
-  wfLocalUrl( "Specjalna:Userlogin" ) . "\">zalogowanym</a>
+  "{{localurle:Specjalna:Userlogin}}\">zalogowanym</a>
 użytkownikiem aby móc przenieść stronę.",
 "newtitle" => "Nowy tytuł",
 "movepagebtn" => "Przenieś stronę",
@@ -1048,163 +1023,93 @@ Wybierz, proszę, nową nazwę.",
 "movetalk" => "Przenieś także stronę <i>Dyskusji</i>, jeśli to możliwe.",
 "talkpagemoved" => "Odpowiednia strona z <i>Dyskusją</i> także została przeniesiona.",
 "talkpagenotmoved" => "Odpowiednia strona z <i>Dyskusją</i> <strong>nie</strong> została przeniesiona.",
+# Math
+    	'mw_math_png' => "Zawsze jako PNG",
+        'mw_math_simple' => "HTML dla prostych, dla reszty PNG",
+        'mw_math_html' => "Spróbuj HTML; jeśli zawiedzie, to PNG",
+        'mw_math_source' => "Pozostaw w TeXu (tekst)",
+        'mw_math_modern' => "HTML, dla nowszych przeglądarek",
+	'mw_math_mathml' => 'MathML'
 
 );
 
 class LanguagePl extends LanguageUtf8 {
-
-        function getDefaultUserOptions () {
-                $opt = Language::getDefaultUserOptions();
-                return $opt;
-        }
 	
-        function getNamespaces() {
-                global $wgNamespaceNamesPl;
-                return $wgNamespaceNamesPl;
-        }
+	function getNamespaces() {
+		global $wgNamespaceNamesPl;
+		return $wgNamespaceNamesPl;
+	}
 
-        function getNsText( $index ) {
-                global $wgNamespaceNamesPl;
-                return $wgNamespaceNamesPl[$index];
-        }
+	function getNsText( $index ) {
+		global $wgNamespaceNamesPl;
+		return $wgNamespaceNamesPl[$index];
+	}
 
-        function getNsIndex( $text ) {
-                global $wgNamespaceNamesPl;
+	function getNsIndex( $text ) {
+		global $wgNamespaceNamesPl;
 
-                foreach ( $wgNamespaceNamesPl as $i => $n ) {
-                        if ( 0 == strcasecmp( $n, $text ) ) { return $i; }
-                }
-                return false;
-        }
+		foreach ( $wgNamespaceNamesPl as $i => $n ) {
+			if ( 0 == strcasecmp( $n, $text ) ) { return $i; }
+		}
+		return false;
+	}
 
-        function getQuickbarSettings() {
-                global $wgQuickbarSettingsPl;
-                return $wgQuickbarSettingsPl;
-        }
+	function getQuickbarSettings() {
+		global $wgQuickbarSettingsPl;
+		return $wgQuickbarSettingsPl;
+	}
 
-        function getSkinNames() {
-                global $wgSkinNamesPl;
-                return $wgSkinNamesPl;
-        }
+	function getMonthNameGen( $key ) {
+		global $wgMonthNamesGenEn;
+		return wfMsgUTF8( $wgMonthNamesGenEn[$key-1] );
+	}
 
-        function getMathNames() { 
-                global $wgMathNamesPl; 
-                return $wgMathNamesPl; 
-    }
+	function date( $ts, $adj = false ) {
+		if ( $adj ) { $ts = $this->userAdjust( $ts ); }
 
-        function getUserToggles() {
-                global $wgUserTogglesPl;
-                return $wgUserTogglesPl;
-        }
+		$d = (0 + substr( $ts, 6, 2 )) . 
+		  " " . $this->getMonthAbbreviation( substr( $ts, 4, 2 ) ) .
+		  " " . substr( $ts, 0, 4 );
+		return $d;
+	}
 
-        function getMonthName( $key )
-        {
-                global $wgMonthNamesPl;
-                return $wgMonthNamesPl[$key-1];
-        }
+	function getValidSpecialPages() {
+		global $wgValidSpecialPagesPl;
+		return $wgValidSpecialPagesPl;
+	}
 
-        function getMonthNameGen( $key )
-        {
-                global $wgMonthNamesGenPl;
-                return $wgMonthNamesGenPl[$key-1];
-        }
+	function getSysopSpecialPages() {
+		global $wgSysopSpecialPagesPl;
+		return $wgSysopSpecialPagesPl;
+	}
 
-        function getMonthAbbreviation( $key )
-        {
-                global $wgMonthAbbreviationsPl;
-                return $wgMonthAbbreviationsPl[$key-1];
-        }
+	function getDeveloperSpecialPages() {
+		global $wgDeveloperSpecialPagesPl;
+		return $wgDeveloperSpecialPagesPl;
+	}
 
-        function getWeekdayName( $key )
-        {
-                global $wgWeekdayNamesPl;
-                return $wgWeekdayNamesPl[$key-1];
-        }
+	function getMessage( $key ) {
+		global $wgAllMessagesPl;
+		if(array_key_exists($key, $wgAllMessagesPl))
+			return $wgAllMessagesPl[$key];
+		else
+			return parent::getMessage($key);
+	}
 
-        function userAdjust( $ts )
-        {
-                global $wgUser;
+	# Check for Latin-2 backwards-compatibility URLs
+	function fallback8bitEncoding() {
+		return "iso-8859-2";
+	}
 
-                $diff = $wgUser->getOption( "timecorrection" );
-                if ( ! $diff ) { $diff = 0; }
-                if ( 0 == $diff ) { return $ts; }
-
-                $t = mktime( ( (int)substr( $ts, 8, 2) ) + $diff,
-                  (int)substr( $ts, 10, 2 ), (int)substr( $ts, 12, 2 ),
-                  (int)substr( $ts, 4, 2 ), (int)substr( $ts, 6, 2 ),
-                  (int)substr( $ts, 0, 4 ) );
-                return date( "YmdHis", $t );
-        }
-
-        function date( $ts, $adj = false )
-        {
-                if ( $adj ) { $ts = $this->userAdjust( $ts ); }
-
-                $d = (0 + substr( $ts, 6, 2 )) . 
-                  " " . $this->getMonthAbbreviation( substr( $ts, 4, 2 ) ) .
-                  " " . substr( $ts, 0, 4 );
-                return $d;
-        }
-
-        function time( $ts, $adj = false )
-        {
-                if ( $adj ) { $ts = $this->userAdjust( $ts ); }
-
-                $t = substr( $ts, 8, 2 ) . ":" . substr( $ts, 10, 2 );
-                return $t;
-        }
-
-        function timeanddate( $ts, $adj = false )
-        {
-                return $this->time( $ts, $adj ) . ", " . $this->date( $ts, $adj );
-        }
-
-        function rfc1123( $ts )
-        {
-                return date( "D, d M Y H:i:s T", $ts );
-        }
-
-        function getValidSpecialPages()
-        {
-                global $wgValidSpecialPagesPl;
-                return $wgValidSpecialPagesPl;
-        }
-
-        function getSysopSpecialPages()
-        {
-                global $wgSysopSpecialPagesPl;
-                return $wgSysopSpecialPagesPl;
-        }
-
-        function getDeveloperSpecialPages()
-        {
-                global $wgDeveloperSpecialPagesPl;
-                return $wgDeveloperSpecialPagesPl;
-        }
-
-        function getMessage( $key )
-        {
-                global $wgAllMessagesPl;
-        if(array_key_exists($key, $wgAllMessagesPl))
-                        return $wgAllMessagesPl[$key];
-                else
-                        return Language::getMessage($key);
-        }
-
-        # Inherit ucfirst() and stripForSearch() from LanguageUtf8
-
-        function checkTitleEncoding( $s ) {
-        # Check for Latin-2 backwards-compatibility URLs
-                $ishigh = preg_match( '/[\x80-\xff]/', $s);
-                $isutf = preg_match( '/^([\x00-\x7f]|[\xc0-\xdf][\x80-\xbf]|' .
-                '[\xe0-\xef][\x80-\xbf]{2}|[\xf0-\xf7][\x80-\xbf]{3})+$/', $s );
-        
-        if($ishigh and !$isutf)
-                return iconv( "ISO-8859-2", "UTF-8", $s );
-        
-        return $s;
-        }
+	var $digitTransTable = array(
+		',' => '&nbsp;',
+		'.' => ','
+	);
 
+	function formatNum( $number ) {
+		global $wgTranslateNumerals;
+		return $wgTranslateNumerals ? strtr($number, $this->digitTransTable ) : $number;
+	}
 }
 
 ?>
