@@ -6,8 +6,8 @@
 -- 2002-12-16, 2003-01-25 Brion VIBBER <brion@pobox.com>
 
 -- Creating searchindex table...
-DROP TABLE IF EXISTS searchindex;
-CREATE TABLE searchindex (
+DROP TABLE IF EXISTS /*$wgDBprefix*/searchindex;
+CREATE TABLE /*$wgDBprefix*/searchindex (
   si_page int(8) unsigned NOT NULL,
   si_title varchar(255) NOT NULL default '',
   si_text mediumtext NOT NULL default '',
@@ -15,19 +15,19 @@ CREATE TABLE searchindex (
 ) TYPE=MyISAM PACK_KEYS=1;
 
 -- Copying data into new table...
-INSERT INTO searchindex
+INSERT INTO /*$wgDBprefix*/searchindex
   (si_page,si_title,si_text)
   SELECT
     cur_id,cur_ind_title,cur_ind_text
-    FROM cur;
+    FROM /*$wgDBprefix*/cur;
 
 
 -- Creating fulltext index...
-ALTER TABLE searchindex
+ALTER TABLE /*$wgDBprefix*/searchindex
   ADD FULLTEXT si_title (si_title),
   ADD FULLTEXT si_text (si_text);
 
 -- Dropping index columns from cur table.
-ALTER TABLE cur
+ALTER TABLE /*$wgDBprefix*/cur
   DROP COLUMN cur_ind_title,
   DROP COLUMN cur_ind_text;
